@@ -1,12 +1,13 @@
-import codecs
-import os
-import sys
-import shutil
-import tempfile
-import pkg_resources
-import logging
-from random import randint
+from base64 import urlsafe_b64encode
 from paste.script.templates import var
+from random import randint
+import codecs
+import logging
+import os
+import pkg_resources
+import shutil
+import sys
+import tempfile
 
 try:
     from hashlib import sha1
@@ -29,13 +30,6 @@ class ask_var(var):
         if self.getter is None:
             self.getter = lambda x, y: self.default
 
-
-def get_var(vars, name):
-    for var in vars:
-        if var.name == name:
-            return var
-
-
 def create_buildout_default_file():
     default_dir = os.path.join(HOME, '.buildout')
     if not os.path.isdir(default_dir):
@@ -57,15 +51,17 @@ eggs-directory = %s
         config_file.write(contents)
         config_file.close()
 
-def get_sha1_encoded_string(passwd):
-    """Encode the given `string` using SHA1.
+def get_ssha_encoded_string(password):
+    """Encode the given `string` using "Secure" SHA.
+
+    Taken from zope.password.password, however grokproject itself
+    cannot depend on that package.
     """
     encoder = codecs.getencoder('utf-8')
-    salt = "%08x" % randint(0, 0xffffffff)
-    # This is apparently a wrong use of salt, but the old SHA1
-    # password manager of `zope.app.authentication` handles it this way.
-    result = salt + sha1(encoder(passwd)[0]).hexdigest()
-    return result
+    hash = sha1(encoder(password)[0])
+    salt = os.urandom(4)
+    hash.update(salt)
+    return '{SSHA}' + urlsafe_b64encode(hash.digest() + salt)
 
 def get_boolean_value_for_option(vars, option):
     value = vars.get(option.name)
@@ -141,15 +137,6 @@ def run_buildout(verbose=False):
         remove_old_logger_handlers()
 
     print "Invoking zc.buildout..."
-    
-    # First we install eggbasket.  This is also done in the
-    # bootstrap.py, but that is not actually called by the bootstrap
-    # lines above...
-    #
-    # Note: we do not want to make this either quiet or verbose: quiet
-    # is too quiet and verbose is too verbose. :-/
-    zc.buildout.buildout.main(['install', 'eggbasket'])    
-    remove_old_logger_handlers()
 
     # Now do the rest of the install.
     zc.buildout.buildout.main(extra_args + ['install'])
@@ -166,41 +153,3 @@ def remove_old_logger_handlers():
         for handler in logger.handlers:
             logger.removeHandler(handler)
     return
-
-
-def required_grok_version(versionfile):
-    for line in versionfile.split('\n'):
-        if line.startswith('grok ='):
-            return line.split(' ')[-1]
-
-
-def extend_versions_cfg(versions_cfg, for_zopectl=False):
-    """Add additional package versions for versions.cfg.
-    
-    We only add eggs that are not already included in versions.cfg
-    fetched from the release info URL (usually grok.zope.org/releaseinfo).
-    """
-    here = os.path.dirname(__file__)
-    if for_zopectl:
-        additional_eggs = open(
-            os.path.join(here, 'ext_eggs_zctl.cfg'), 'rb').read()
-    else:
-        additional_eggs = open(
-            os.path.join(here, 'ext_eggs_paster.cfg'), 'rb').read()
-        
-    # Create a list of already pinned eggs...
-    pinned = list()
-    for line in versions_cfg.split('\n'):
-        if not " " in line:
-            continue
-        pinned.append(line.split(' ')[0].strip())
-
-    result = ''
-    for line in additional_eggs.split('\n'):
-        if ' ' in line:
-            if line.split(' ')[0].strip() in pinned:
-                # Skip eggs already in versions.cfg...
-                continue
-            pass
-        result += '%s\n' % line
-    return result
